==> breeze_website_builder_6.5.02.tar.gz: manage/plugins/lang/gallery/kn.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "ಲೈಟ್ಬಾಕ್ಸ್ನಲ್ಲಿ gallary ನಿಯತಾಂಕಗಳನ್ನು ನಿರ್ವಹಿಸಿ");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "ಗ್ಯಾಲರಿ ನಿರ್ವಹಿಸಿ");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "ಪೂರ್ಣ ಗಾತ್ರ ಇಮೇಜ್ ಅಗಲ");
define('MANAGE_GALLERY_FULL_HEIGHT', "ಪೂರ್ಣ ಗಾತ್ರ ಇಮೇಜ್ ಎತ್ತರ");
define('MANAGE_GALLERY_THUMB_WIDTH', "ಥಂಬ್ನೇಲ್ ಇಮೇಜ್ ಅಗಲ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "ಥಂಬ್ನೇಲ್ ಇಮೇಜ್ ಎತ್ತರ");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "ಹೆಬ್ಬೆರಳು ಆಕಾರ ಅನುಪಾತ ಉಳಿಸಿಕೊ");
define('MANAGE_GALLERY_SHOW_TITLES', "ಶೀರ್ಷಿಕೆ ಶೋ");
define('MANAGE_GALLERY_DISABLE_SORT', "ವಿಂಗಡಿಸಿ ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಿ");
define('MANAGE_GALLERY_DELETE_IMAGE', "ಚಿತ್ರ ಅಳಿಸಿ");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ಆರ್ಡರ್ ವಿಂಗಡಿಸು ಉಳಿಸಿ");
define('MANAGE_GALLERY_PUBLISH_MSG', "ಪ್ರಕಟಿಸಲು &#39;ಅಪ್ಡೇಟ್&#39; ಕ್ಲಿಕ್ ಮಾಡಿ <br /> ನಿಮ್ಮ ಅಪ್ಲೋಡ್ ಚಿತ್ರಗಳ.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "ಎಲ್ಲಾ ಚಿತ್ರಗಳನ್ನು ಗಾತ್ರ ಮಾಡಲಾಗಿದೆ ಮತ್ತು ಸೆಟ್ಟಿಂಗ್ಗಳನ್ನು ಉಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "ಮರುಗಾತ್ರಗೊಳಿಸಲು ಚಿತ್ರಗಳನ್ನು ಅಥವಾ ಸೆಟ್ಟಿಂಗ್ಗಳನ್ನು ಉಳಿಸುವಲ್ಲಿ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "ನಿಮ್ಮ ಚಿತ್ರ (ಗಳು) ಅಪ್ಲೋಡ್ ಮಾಡಲಾಗಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "ನಿಮ್ಮ ಚಿತ್ರ (ಗಳು) ಅಪ್ಲೋಡ್ ಮಾಡುವಾಗ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ನೀವು ಅಪ್ಲೋಡ್ ಮಾಡಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಫೈಲ್ ಒಂದು ಚಿತ್ರವಲ್ಲ.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ನೀವು ಅಪ್ಲೋಡ್ ಮಾಡಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಫೈಲ್ ತುಂಬಾ ದೊಡ್ಡದಾಗಿದೆ.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "ಶೀರ್ಷಿಕೆ ಉಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "ನೀವು ಅಳಿಸಬಹುದು ಬಯಸಿದ್ದೀರಾ");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "ಚಿತ್ರ ಅಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "ಚಿತ್ರ ಅಳಿಸುವಲ್ಲಿ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "ನಿಯತಾಂಕಗಳನ್ನು ಉಳಿತಾಯ ಮತ್ತು ಮರುಗಾತ್ರಗೊಳಿಸಲು ಚಿತ್ರಗಳನ್ನು, ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "ಅಪ್ಲೋಡ್ ಮಾಡಲಾಗುತ್ತಿದೆ, ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ವಿಂಗಡಣಾ ಕ್ರಮ ಉಳಿಸಲಾಗಿಲ್ಲ. ನೀವು ವಿಂಗಡಣಾ ಕ್ರಮ ಉಳಿಸಲು ಬಯಸುವಿರಾ?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ಚಿತ್ರ ವಿಂಗಡಣಾ ಕ್ರಮ ಉಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "ಚಿತ್ರ ರೀತಿಯ ಉಳಿಸುವ ದೋಷ ಸಂಭವಿಸಿದೆ.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/kn.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "ಲೈಟ್ಬಾಕ್ಸ್ನಲ್ಲಿ gallary ನಿಯತಾಂಕಗಳನ್ನು ನಿರ್ವಹಿಸಿ");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "ಗ್ಯಾಲರಿ ನಿರ್ವಹಿಸಿ");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "ಪೂರ್ಣ ಗಾತ್ರ ಇಮೇಜ್ ಅಗಲ");
define('MANAGE_GALLERY_FULL_HEIGHT', "ಪೂರ್ಣ ಗಾತ್ರ ಇಮೇಜ್ ಎತ್ತರ");
define('MANAGE_GALLERY_THUMB_WIDTH', "ಥಂಬ್ನೇಲ್ ಇಮೇಜ್ ಅಗಲ");
define('MANAGE_GALLERY_THUMB_HEIGHT', "ಥಂಬ್ನೇಲ್ ಇಮೇಜ್ ಎತ್ತರ");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "ಹೆಬ್ಬೆರಳು ಆಕಾರ ಅನುಪಾತ ಉಳಿಸಿಕೊ");
define('MANAGE_GALLERY_SHOW_TITLES', "ಶೀರ್ಷಿಕೆ ಶೋ");
define('MANAGE_GALLERY_DISABLE_SORT', "ವಿಂಗಡಿಸಿ ನಿಷ್ಕ್ರಿಯಗೊಳಿಸಿ");
define('MANAGE_GALLERY_DELETE_IMAGE', "ಚಿತ್ರ ಅಳಿಸಿ");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "ಆರ್ಡರ್ ವಿಂಗಡಿಸು ಉಳಿಸಿ");
define('MANAGE_GALLERY_PUBLISH_MSG', "ಪ್ರಕಟಿಸಲು &#39;ಅಪ್ಡೇಟ್&#39; ಕ್ಲಿಕ್ ಮಾಡಿ <br /> ನಿಮ್ಮ ಅಪ್ಲೋಡ್ ಚಿತ್ರಗಳ.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "ಎಲ್ಲಾ ಚಿತ್ರಗಳನ್ನು ಗಾತ್ರ ಮಾಡಲಾಗಿದೆ ಮತ್ತು ಸೆಟ್ಟಿಂಗ್ಗಳನ್ನು ಉಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "ಮರುಗಾತ್ರಗೊಳಿಸಲು ಚಿತ್ರಗಳನ್ನು ಅಥವಾ ಸೆಟ್ಟಿಂಗ್ಗಳನ್ನು ಉಳಿಸುವಲ್ಲಿ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "ನಿಮ್ಮ ಚಿತ್ರ (ಗಳು) ಅಪ್ಲೋಡ್ ಮಾಡಲಾಗಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "ನಿಮ್ಮ ಚಿತ್ರ (ಗಳು) ಅಪ್ಲೋಡ್ ಮಾಡುವಾಗ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "ನೀವು ಅಪ್ಲೋಡ್ ಮಾಡಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಫೈಲ್ ಒಂದು ಚಿತ್ರವಲ್ಲ.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "ನೀವು ಅಪ್ಲೋಡ್ ಮಾಡಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಫೈಲ್ ತುಂಬಾ ದೊಡ್ಡದಾಗಿದೆ.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "ಶೀರ್ಷಿಕೆ ಉಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "ನೀವು ಅಳಿಸಬಹುದು ಬಯಸಿದ್ದೀರಾ");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "ಚಿತ್ರ ಅಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "ಚಿತ್ರ ಅಳಿಸುವಲ್ಲಿ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "ನಿಯತಾಂಕಗಳನ್ನು ಉಳಿತಾಯ ಮತ್ತು ಮರುಗಾತ್ರಗೊಳಿಸಲು ಚಿತ್ರಗಳನ್ನು, ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "ಅಪ್ಲೋಡ್ ಮಾಡಲಾಗುತ್ತಿದೆ, ದಯವಿಟ್ಟು ನಿರೀಕ್ಷಿಸಿ ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "ವಿಂಗಡಣಾ ಕ್ರಮ ಉಳಿಸಲಾಗಿಲ್ಲ. ನೀವು ವಿಂಗಡಣಾ ಕ್ರಮ ಉಳಿಸಲು ಬಯಸುವಿರಾ?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "ಚಿತ್ರ ವಿಂಗಡಣಾ ಕ್ರಮ ಉಳಿಸಲಾಗಿದೆ.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "ಚಿತ್ರ ರೀತಿಯ ಉಳಿಸುವ ದೋಷ ಸಂಭವಿಸಿದೆ.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "ನೀವು ಅಪ್‌ಲೋಡ್ ಮಾಡಲು ಪ್ರಯತ್ನಿಸುತ್ತಿರುವ ಫೈಲ್ &#39;ಅಪ್‌ಲೋಡ್_ಮ್ಯಾಕ್ಸ್_ಫೈಲ್‌ಸೈಜ್&#39; ಅಥವಾ &#39;ಪೋಸ್ಟ್_ಮ್ಯಾಕ್ಸ್_ಸೈಜ್&#39; ಪಿಎಚ್ಪಿ ಸೆಟ್ಟಿಂಗ್‌ಗಳಿಗಿಂತ ದೊಡ್ಡದಾಗಿದೆ. ಈ ಮಿತಿಗಳನ್ನು ಹೆಚ್ಚಿಸಲು ನಿಮ್ಮ ಸಿಸ್ಟಮ್ ನಿರ್ವಾಹಕರನ್ನು ಸಂಪರ್ಕಿಸಿ.");
?>
